@@ -195,102 +195,16 @@ void YouTube::parseVideoPage() {
 
 QString YouTube::decryptSignature(const QString &s) {
     QString signature;
+    QStringList slist = this->reverseString(s).split("", QString::SkipEmptyParts);
 
-    switch (s.size()) {
-    case 88: {
-        signature = s.at(48)
-                + this->reverseString(s.mid(68, 14))
-                + s.at(82)
-                + this->reverseString(s.mid(63, 4))
-                + s.at(85)
-                + this->reverseString(s.mid(49, 13))
-                + s.at(67)
-                + this->reverseString(s.mid(13, 35))
-                + s.at(3)
-                + this->reverseString(s.mid(4, 8))
-                + s.at(2)
-                + s.at(12);
-    }
-        break;
-    case 87: {
-        signature = s.at(62)
-                + this->reverseString(s.mid(63, 20))
-                + s.at(83)
-                + this->reverseString(s.mid(53, 9))
-                + s.at(0)
-                + this->reverseString(s.mid(3, 49));
-    }
-        break;
-    case 86: {
-        signature = s.mid(2, 61)
-                + s.at(82)
-                + s.mid(64, 18)
-                + s.at(63);
-    }
-        break;
-    case 85: {
-        signature = s.at(76)
-                + this->reverseString(s.mid(77, 6))
-                + s.at(83)
-                + this->reverseString(s.mid(61, 15))
-                + s.at(0)
-                + this->reverseString(s.mid(51, 9))
-                + s.at(1)
-                + this->reverseString(s.mid(3, 47));
-    }
-        break;
-    case 84: {
-        signature = this->reverseString(s.mid(37, 47))
-                + s.at(2)
-                + this->reverseString(s.mid(27, 9))
-                + s.at(3)
-                + this->reverseString(s.mid(4, 22))
-                + s.at(26);
-    }
-        break;
-    case 83: {
-        signature = s.at(6)
-                + s.mid(3, 3)
-                + s.at(33)
-                + s.mid(7, 17)
-                + s.at(0)
-                + s.mid(25, 8)
-                + s.at(53)
-                + s.mid(34, 19)
-                + s.at(24)
-                + s.mid(54);
-    }
-        break;
-    case 82: {
-        signature = s.at(36)
-                + this->reverseString(s.mid(68, 13))
-                + s.at(81)
-                + this->reverseString(s.mid(41, 26))
-                + s.at(33)
-                + this->reverseString(s.mid(37, 3))
-                + s.at(40)
-                + s.at(35)
-                + s.at(0)
-                + s.at(67)
-                + this->reverseString(s.mid(1, 32))
-                + s.at(34);
-    }
-        break;
-    case 81: {
-        signature = s.at(6)
-                + s.mid(3, 3)
-                + s.at(33)
-                + s.mid(7, 17)
-                + s.at(0)
-                + s.mid(25, 8)
-                + s.at(2)
-                + s.mid(34, 19)
-                + s.at(24)
-                + s.mid(54, 27);
-    }
-        break;
-    default:
-        break;
+    if (slist.size() > 65) {
+        slist.removeFirst();
+        slist.removeFirst();
+
+        QString b = slist.at(0);
+        slist.replace(0, slist.at(65 % slist.size()));
+        slist.replace(65, b);
+        signature = this->reverseString(slist.join(""));
     }
 
     return signature;
